@@ -1,34 +1,30 @@
 #' Plot a ggmap object
 #'
-#' ggmap plots the raster object produced by \code{\link{get_map}}.
+#' ggmap plots the raster object produced by [get_map()].
 #'
 #' @param ggmap an object of class ggmap (from function get_map)
-#' @param extent how much of the plot should the map take up?
-#'   "normal", "device", or "panel" (default)
+#' @param extent how much of the plot should the map take up? "normal",
+#'   "device", or "panel" (default)
 #' @param base_layer a ggplot(aes(...), ...) call; see examples
-#' @param maprange logical for use with base_layer; should the map
-#'   define the x and y limits?
-#' @param legend "left", "right" (default), "bottom", "top",
-#'   "bottomleft", "bottomright", "topleft", "topright", "none"
-#'   (used with extent = "device")
-#' @param padding distance from legend to corner of the plot (used
-#'   with legend, formerly b)
-#' @param darken vector of the form c(number, color), where number
-#'   is in [0, 1] and color is a character string indicating the
-#'   color of the darken.  0 indicates no darkening, 1 indicates a
-#'   black-out.
-#' @param b Deprecated, renamed to `padding`. Overrides any
-#'   `padding` argument.
-#' @param fullpage Deprecated, equivalent to `extent = "device"`
-#'   when `TRUE`. Overrides any `extent` argument.
-#' @param expand Deprecated, equivalent to `extent = "panel"`
-#'   when `TRUE` and `fullpage` is `FALSE`. When `fullpage`
-#'   is `FALSE` and `expand` is `FALSE`, equivalent to
-#'   `extent="normal"`. Overrides any `extent` argument.
+#' @param maprange logical for use with base_layer; should the map define the x
+#'   and y limits?
+#' @param legend "left", "right" (default), "bottom", "top", "bottomleft",
+#'   "bottomright", "topleft", "topright", "none" (used with extent = "device")
+#' @param padding distance from legend to corner of the plot (used with legend,
+#'   formerly b)
+#' @param darken vector of the form c(number, color), where number is in (0,1)
+#'   and color is a character string indicating the color of the darken.  0
+#'   indicates no darkening, 1 indicates a black-out.
+#' @param b Deprecated, renamed to `padding`. Overrides any `padding` argument.
+#' @param fullpage Deprecated, equivalent to `extent = "device"` when `TRUE`.
+#'   Overrides any `extent` argument.
+#' @param expand Deprecated, equivalent to `extent = "panel"` when `TRUE` and
+#'   `fullpage` is `FALSE`. When `fullpage` is `FALSE` and `expand` is `FALSE`,
+#'   equivalent to `extent="normal"`. Overrides any `extent` argument.
 #' @param ... ...
 #' @return a ggplot object
-#' @author David Kahle \email{david.kahle@@gmail.com}
-#' @seealso \code{\link{get_map}}, \code{\link{qmap}}
+#' @author David Kahle \email{david@@kahle.io}
+#' @seealso [get_map()], [qmap()]
 #' @export ggmap inset inset_raster
 #' @examples
 #'
@@ -459,7 +455,7 @@ ggmap <- function(ggmap, extent = "panel", base_layer, maprange = FALSE,
 
   # check arguments
   if(class(ggmap)[1] != "ggmap"){
-    stop("ggmap plots objects of class ggmap, see ?get_map", call. = FALSE)
+    cli::cli_abort("{.fn ggmap::ggmap} only plots objects of class {.code ggmap}")
   }
 
   match.arg(legend, c("right", "left", "bottom", "top",
@@ -586,17 +582,17 @@ ggmap <- function(ggmap, extent = "panel", base_layer, maprange = FALSE,
 
 #' Don't use this function, use ggmap.
 #'
-#' ggmap plots the raster object produced by \code{\link{get_map}}.
+#' ggmap plots the raster object produced by [get_map()].
 #'
-#' @param ggmap an object of class ggmap (from function get_map)
+#' @param ggmap an object of class ggmap (from function [get_map()])
 #' @param fullpage logical; should the map take up the entire viewport?
 #' @param base_layer a ggplot(aes(...), ...) call; see examples
 #' @param maprange logical for use with base_layer; should the map define the x and y limits?
 #' @param expand should the map extend to the edge of the panel? used with base_layer and maprange=TRUE.
 #' @param ... ...
 #' @return a ggplot object
-#' @author David Kahle \email{david.kahle@@gmail.com}
-#' @seealso \code{\link{get_map}}, \code{\link{qmap}}
+#' @author David Kahle \email{david@@kahle.io}
+#' @seealso [get_map()], [qmap()]
 #' @export
 #' @examples
 #' \dontrun{
